# - AthenaTwitchLib -
[![pypi](https://img.shields.io/pypi/v/AthenaTwitchLib)](https://pypi.org/project/AthenaTwitchLib/) [![GitHub license](https://img.shields.io/github/license/DirectiveAthena/AthenaTwitchLib)](https://github.com/DirectiveAthena/VerSC-AthenaColor/blob/master/LICENSE) [![Discord](https://img.shields.io/discord/814599159926620160?color=maroon)](https://discord.gg/6JcDbhXkCH) [![Downloads](https://pepy.tech/badge/athenatwitchbot)](https://pepy.tech/project/athenatwitchbot)

--- 
## Package Details
#### Details and features 
- A library to create Twitch Chat Bots
  - hard coded commands
  - hard coded tasks
  - Bots have the ability to pull commands from a database
    - Currently supported databases: *Sqlite* (more will come in the future)
  - Logging is handled by other Process
    - Logs are stored to a Sqlite file

- Features that are planned but still being worked on
  - Twitch Helix API connector
  - Task pulling from a database
  - ...

#### Python Version
- Supported Python versions: **3.11**
  - Other older versions of Python are not going to be supported.

---

## Example
**Currently, still in Alpha phase. Will have a good example working once version 1.0.0 is released**

## Install
To install the package in your Python environment

```
pip install AthenaTwitchLib --upgrade
```

---

## Links 
Project files can be found at:    
- [GitHub Repo](https://github.com/DirectiveAthena/AthenaTwitchLib)     
- [Pypi link](https://pypi.org/project/AthenaTwitchLib/)    

---
Made By Andreas Sas,` 2022`
